# Bitcart usage examples

This folder contains examples of using Bitcart.

Examples requirements for that folder is in requirements.txt(actually just Bitcart SDK)

Examples:

- Full Bitcart API usage example: full.py
- Get transaction by tx hash(CLI): gettx.py
- Get wallet onchain and offchain(lightning) balance: getbalance.py
- Pay to some address(CLI): donateto.py
- Websocket example: websocket.py
- APIManager example: manager.py

Full example(telegram bot) is available at atomic_tipbot directory
